#
# spec file for package python
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without  test
%bcond_without  test_twisted
%define psuffix -test
%else
%bcond_without  test
%bcond_with     test_twisted
%endif
Name:           python-tblib%{?psuffix}
Version:        1.6.0
Release:        bp155.2.12
Summary:        Traceback serialization library
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ionelmc/python-tblib
Source:         https://files.pythonhosted.org/packages/source/t/tblib/tblib-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test_twisted}
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module tblib == %{version}}
%endif
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six}
%endif
Requires:       python-six
BuildArch:      noarch

%python_subpackages

%description
Traceback serialization library.

It allows you to:

* Pickle  tracebacks and raise exceptions with pickled tracebacks in
  different processes. This allows better error handling when running
  code over multiple processes (imagine multiprocessing, billiard,
  futures, celery etc).
* Create traceback objects from strings (the ``from_string`` method).
  *No pickling is used*.
* Serialize tracebacks to/from plain dicts (the ``from_dict`` and
  ``to_dict`` methods). *No pickling is used*.
* Raise the tracebacks created from the aforementioned sources.

Again, note that using the pickle support is completely optional. You
are solely responsible for security problems should you decide to use
the pickle support.

%prep
%setup -q -n tblib-%{version}

%build
%python_build

%install
%if "%{flavor}" != "test"
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if "%{flavor}" != "test"
%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/*
%endif

%changelog
* Sun Dec 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Move the Twisted test out of the main package to avoid the
  Twisted dependency chain.
* Sun Dec 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- version update to 1.6.0
  * When pickling an Exception, also pickle its traceback and the Exception
    chain (raise ... from ...). Contributed by Guido Imperiale in #53.
- version update to 1.5.0
  * Added support for Python 3.8. Contributed by Victor Stinner in #42.
  * Removed support for end of life Python 3.4.
  * Few CI improvements and fixes.
* Mon May  6 2019 pgajdos@suse.com
- version update to 1.4.0
  * Remove support for end of life Python 3.3.
  * Fixed tests for Python 3.7. Contributed by Elliott Sales de Andrade in
    `#36 <https://github.com/ionelmc/python-tblib/issues/36>`_.
  * Fixed compatibility issue with Twised (``twisted.python.failure.Failure``
    expected a ``co_code`` attribute).
- deleted patches
  - 0001-Patch-tests-against-Python-3.7.patch (upstreamed)
* Sun Mar  3 2019 John Vandenberg <jayvdb@gmail.com>
- Remove bcond_with test preventing the tests from running,
  and fix the %%check
- Remove unnecessary dependency on tox, flake8 and 9 other deps
- Add 0001-Patch-tests-against-Python-3.7.patch to workaround
  Python 3.7 test failure.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- Use %%license macro for license.
* Mon Aug 14 2017 toddrme2178@gmail.com
- Initial version
